@@ -1,46 +1,45 @@
 context("retrieveFactory")
 
-resetEnv <- function() {
-  if (Sys.getenv('OP_TYPE_FACTORY') != '') Sys.setenv('OP_TYPE_FACTORY' = '')
+resetOptions <- function() {
+  options('op_type_factory' = NULL)
 }
 
-setEnv <- function(rVariableName_s_1) {
-  Sys.setenv('OP_TYPE_FACTORY' = rVariableName_s_1)
+setOptions <- function(rObject_) {
+  options('op_type_factory' = rObject_)
 }
 
-getEnv <- function() { Sys.getenv('OP_TYPE_FACTORY') }
+getOptions <- function() { options('op_type_factory') }
 
-resetEnv()
+resetOptions()
 r1 <- nrow(retrieveFactory()$getRecordedTypes()[suffix == 'xyz'])
-#cat('r1', r1, '\n')
 
 my_factory <- retrieveFactory()
 my_factory$addSuffix('xyz', 'xyz', function(o_1l_) is(o_1l_, 'xyz'))
 
 # no environment variable associated
-setEnv('')
+setOptions('')
 r2 <- nrow(retrieveFactory()$getRecordedTypes()[suffix == 'xyz'])
 #cat('r2', r2, '\n')
 
-# set incorrect R variable name
-setEnv('my_factor')
+# set incorrect R variable - passed name not object
+setOptions('my_factory')
 r3 <- nrow(retrieveFactory()$getRecordedTypes()[suffix == 'xyz'])
 #cat('r3', r3, '\n')
 
 # set correct R variable name
-setEnv('my_factory')
+setOptions(my_factory)
 r4 <- nrow(retrieveFactory()$getRecordedTypes()[suffix == 'xyz']) + 0
 #cat('r4', r4, '\n')
 
 # R variable exists but no environement variable set
-resetEnv()
+resetOptions()
 r5 <- nrow(retrieveFactory()$getRecordedTypes()[suffix == 'xyz'])
 #cat('r5', r5, '\n')
 
 #
 rm('my_factory')
 ls()
-setEnv('my_factory')
+setOptions('my_factory')
 r6 <- nrow(retrieveFactory()$getRecordedTypes()[suffix == 'xyz'])
 #cat('r6', r6, '\n')
 
